package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERGeneralizedTime;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.DERUTCTime;
import java.util.Enumeration;

public class TBSCertList extends ASN1Encodable {
   ASN1Sequence seq;
   DERInteger version;
   AlgorithmIdentifier signature;
   X509Name issuer;
   Time thisUpdate;
   Time nextUpdate;
   ASN1Sequence revokedCertificates;
   X509Extensions crlExtensions;

   public static TBSCertList getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static TBSCertList getInstance(Object obj) {
      if (obj instanceof TBSCertList) {
         return (TBSCertList)obj;
      } else if (obj instanceof ASN1Sequence) {
         return new TBSCertList((ASN1Sequence)obj);
      } else {
         throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
      }
   }

   public TBSCertList(ASN1Sequence seq) {
      if (seq.size() >= 3 && seq.size() <= 7) {
         int var2 = 0;
         this.seq = seq;
         if (seq.getObjectAt(var2) instanceof DERInteger) {
            int var10002 = var2;
            var2 = 1;
            this.version = DERInteger.getInstance(seq.getObjectAt(var10002));
         } else {
            DERInteger var3;
            var3 = new DERInteger.<init>(0);
            this.version = var3;
         }

         this.signature = AlgorithmIdentifier.getInstance(seq.getObjectAt(var2++));
         this.issuer = X509Name.getInstance(seq.getObjectAt(var2++));
         int var4;
         int var10000 = var4 = var2 + 1;
         this.thisUpdate = Time.getInstance(seq.getObjectAt(var2));
         if (var10000 < seq.size() && (seq.getObjectAt(var4) instanceof DERUTCTime || seq.getObjectAt(var4) instanceof DERGeneralizedTime || seq.getObjectAt(var4) instanceof Time)) {
            this.nextUpdate = Time.getInstance(seq.getObjectAt(var4++));
         }

         if (var4 < seq.size() && !(seq.getObjectAt(var4) instanceof DERTaggedObject)) {
            this.revokedCertificates = ASN1Sequence.getInstance(seq.getObjectAt(var4++));
         }

         if (var4 < seq.size() && seq.getObjectAt(var4) instanceof DERTaggedObject) {
            this.crlExtensions = X509Extensions.getInstance(seq.getObjectAt(var4));
         }

      } else {
         throw new IllegalArgumentException("Bad sequence size: " + seq.size());
      }
   }

   public int getVersion() {
      return this.version.getValue().intValue() + 1;
   }

   public DERInteger getVersionNumber() {
      return this.version;
   }

   public AlgorithmIdentifier getSignature() {
      return this.signature;
   }

   public X509Name getIssuer() {
      return this.issuer;
   }

   public Time getThisUpdate() {
      return this.thisUpdate;
   }

   public Time getNextUpdate() {
      return this.nextUpdate;
   }

   public CRLEntry[] getRevokedCertificates() {
      ASN1Sequence var1;
      if ((var1 = this.revokedCertificates) == null) {
         return new CRLEntry[0];
      } else {
         int var4;
         CRLEntry[] var2 = new CRLEntry[var4 = var1.size()];

         for(int var3 = 0; var3 < var4; ++var3) {
            var2[var3] = new CRLEntry(ASN1Sequence.getInstance(this.revokedCertificates.getObjectAt(var3)));
         }

         return var2;
      }
   }

   public Enumeration getRevokedCertificateEnumeration() {
      ASN1Sequence var1;
      return (Enumeration)((var1 = this.revokedCertificates) == null ? new EmptyEnumeration((EmptyEnumeration)null) : new RevokedCertificatesEnumeration(var1.getObjects()));
   }

   public X509Extensions getExtensions() {
      return this.crlExtensions;
   }

   public DERObject toASN1Object() {
      return this.seq;
   }

   public class CRLEntry extends ASN1Encodable {
      ASN1Sequence seq;
      DERInteger userCertificate;
      Time revocationDate;
      X509Extensions crlEntryExtensions;

      public CRLEntry(ASN1Sequence seq) {
         if (seq.size() >= 2 && seq.size() <= 3) {
            this.seq = seq;
            this.userCertificate = DERInteger.getInstance(seq.getObjectAt(0));
            this.revocationDate = Time.getInstance(seq.getObjectAt(1));
         } else {
            throw new IllegalArgumentException("Bad sequence size: " + seq.size());
         }
      }

      public DERInteger getUserCertificate() {
         return this.userCertificate;
      }

      public Time getRevocationDate() {
         return this.revocationDate;
      }

      public X509Extensions getExtensions() {
         if (this.crlEntryExtensions == null && this.seq.size() == 3) {
            this.crlEntryExtensions = X509Extensions.getInstance(this.seq.getObjectAt(2));
         }

         return this.crlEntryExtensions;
      }

      public DERObject toASN1Object() {
         return this.seq;
      }
   }

   private class EmptyEnumeration implements Enumeration {
      private EmptyEnumeration() {
      }

      // $FF: synthetic method
      EmptyEnumeration(EmptyEnumeration var2) {
         this();
      }

      public boolean hasMoreElements() {
         return false;
      }

      public Object nextElement() {
         return null;
      }
   }

   private class RevokedCertificatesEnumeration implements Enumeration {
      private final Enumeration en;

      RevokedCertificatesEnumeration(Enumeration en) {
         this.en = en;
      }

      public boolean hasMoreElements() {
         return this.en.hasMoreElements();
      }

      public Object nextElement() {
         return TBSCertList.this.new CRLEntry(ASN1Sequence.getInstance(this.en.nextElement()));
      }
   }
}
